@@ -3,7 +3,7 @@ import os
 from os.path import join, expanduser
 
 from invoke.util import six
-from mock import patch, call
+from mock import patch, call, Mock
 import pytest
 from pytest_relaxed import raises
 
@@ -92,7 +92,11 @@ class Config_:
             # which override them, e.g. runner tests around warn=True, etc).
             expected = {
                 "run": {
+                    "asynchronous": False,
+                    "disown": False,
+                    "dry": False,
                     "echo": False,
+                    "echo_format": "\033[1;37m{command}\033[0m",
                     "echo_stdin": None,
                     "encoding": None,
                     "env": {},
@@ -114,11 +118,13 @@ class Config_:
                     "user": None,
                 },
                 "tasks": {
-                    "dedupe": True,
                     "auto_dash_names": True,
                     "collection_name": "tasks",
+                    "dedupe": True,
+                    "executor_class": None,
                     "search_root": None,
                 },
+                "timeouts": {"command": None},
             }
             assert Config.global_defaults() == expected
 
@@ -232,7 +238,7 @@ class Config_:
                 expected = """
 No attribute or config key found for 'nope'
 
-Valid keys: ['run', 'runners', 'sudo', 'tasks']
+Valid keys: ['run', 'runners', 'sudo', 'tasks', 'timeouts']
 
 Valid real attributes: ['clear', 'clone', 'env_prefix', 'file_prefix', 'from_data', 'global_defaults', 'load_base_conf_files', 'load_collection', 'load_defaults', 'load_overrides', 'load_project', 'load_runtime', 'load_shell_env', 'load_system', 'load_user', 'merge', 'pop', 'popitem', 'prefix', 'set_project_location', 'set_runtime_path', 'setdefault', 'update']
 """.strip()  # noqa
@@ -581,7 +587,7 @@ Valid real attributes: ['clear', 'clone', 'env_prefix', 'file_prefix', 'from_dat
             assert c._project_path is None
             c.load_project()
             assert list(c._project.keys()) == []
-            defaults = ["tasks", "run", "runners", "sudo"]
+            defaults = ["tasks", "run", "runners", "sudo", "timeouts"]
             assert set(c.keys()) == set(defaults)
 
         def project_location_can_be_set_after_init(self):
@@ -632,6 +638,21 @@ Valid real attributes: ['clear', 'clone', 'env_prefix', 'file_prefix', 'from_dat
             with pytest.raises(UnpicklableConfigMember, match=expected):
                 c.load_runtime(merge=False)
 
+        @patch("invoke.config.debug")
+        def nonexistent_files_are_skipped_and_logged(self, mock_debug):
+            c = Config()
+            c._load_yml = Mock(side_effect=IOError(2, "aw nuts"))
+            c.set_runtime_path("is-a.yml")  # Triggers use of _load_yml
+            c.load_runtime()
+            mock_debug.assert_any_call("Didn't see any is-a.yml, skipping.")
+
+        @raises(IOError)
+        def non_missing_file_IOErrors_are_raised(self):
+            c = Config()
+            c._load_yml = Mock(side_effect=IOError(17, "uh, what?"))
+            c.set_runtime_path("is-a.yml")  # Triggers use of _load_yml
+            c.load_runtime()
+
     class collection_level_config_loading:
         def performed_explicitly_and_directly(self):
             # TODO: do we want to update the other levels to allow 'direct'
